(ns data-cleaning.map-test
  (:require [clojure.test :refer :all]
            [data-cleaning.map :refer :all]))


;;; tests

(deftest parse-map-properties
  (testing "Map properties should be parsed from the file."
    (
     ; Act
     let [properties (read-properties "test/data_cleaning/test_files/map_properties.asc")]

       ; Assert
       (is (= (get properties :declared-size)
              [3 5]))
       (is (= (get properties :rows)
              [4 4 1 5 4]))
       (is (= (get properties :cell-size)
              200.0))
       (is (= (get properties :left-bottom-corner)
              [1.0 2.0]))
       (is (= (get properties :na-cells)
              {0 [2] 1 [2] 3 [0 1 3 4]})))))

(deftest read-map-test
  (testing "Map matrix should be read from the file."
    (
     ; Act
     let [map (read-map "test/data_cleaning/test_files/map_properties.asc")]

       ; Assert
       (is (= map
              ["u" "2" "-9999" "2"
               "4" "6" "-9999" "4"
               "1"
               "-9999" "-9999" "3" "-9999" "-9999"
               "1" "2" "3" "4"])))))

(deftest na-value-as-string
  (testing "Na value as a string should be supported."
    (
     ; Act
     let [properties (read-properties "test/data_cleaning/test_files/map_NA_string.asc")]

       ; Assert
       (is (= (get properties :na-cells)
              {0 [0]})))))

(deftest read-positions-test
  (testing "Positions of the specified cell value should be read from the file."
    (
     ; Act
     let [positions (read-positions "test/data_cleaning/test_files/mask.asc")]

       ; Assert
       (is (= positions
              {1 [0 3] 4 [3]})))))


;;; test grouping

(deftest read-properties-test
  (testing "Map properties should be read from the file:\n"
    (parse-map-properties)
    (na-value-as-string)))


;;; tests in the namespace

(defn test-ns-hook
  "summary: Explicit definition of tests in the namespace.
   returns: Explicit definition of tests in the namespace."
  []
  (read-properties-test)
  (read-map-test)
  (read-positions-test))
