(ns regression-tests.permutations-test
  (:require [clojure.test :refer :all]
            [regression-tests.permutations :refer :all]
            [utilities.floating-point-comparison :refer :all]))

;;; tests

(deftest permute-r-squared-test
  (testing "Permutation tests on r-squared should be run."
    (
     ; Act
     let [result (permute-r-squared [1.1 1 0.95
                                     1.15 2.1 2.05
                                     3 3.01 3.02 2.9]
                                    [[1 1 4]
                                     [2 3 2]
                                     [2 2 3]
                                     [1.5 1.5 1.5]
                                     [3 3.1 5]
                                     [3.5 3 5.5]
                                     [4 3 6]
                                     [3.8 2.5 6.3]
                                     [3.9 2.7 6.5]
                                     [4.2 3.4 6]]
                                    [[0 2 1 8 3 4 5 6 9 7]
                                     [5 0 1 3 2 4 8 6 7 9]
                                     [0 2 3 5 4 1 6 7 8 9]])]

       ; Assert
       (is (double= (get result :p-value)
                    [1/4 -0.174352447854375 0.674352447854375]))

       (is (double= (get result :sample)
                    [0.946714609703952
                     0.748368711538029
                     0.797480226231733
                     0.699669190844225])))))

(deftest permute-t-stat-test
  (testing "Permutation tests on coefficient's t-stat should be run."
    (
     ; Arrange
     let [y [1.1 1 0.95 1.15 2.1 2.05 3 3.01 3.02 2.9]
          x [[1 1 4] [2 3 2] [2 2 3] [1.5 1.5 1.5] [3 3.1 5] [3.5 3 5.5]
             [4 3 6] [3.8 2.5 6.3] [3.9 2.7 6.5] [4.2 3.4 6]]
          permutations [[0 2 1 8 3 4 5 6 9 7]
                        [5 0 1 3 2 4 8 6 7 9]
                        [0 2 3 5 4 1 6 7 8 9]]]
       ; Act
       (let [p-value1 (permute-t-stat y x permutations 0)
             p-value2 (permute-t-stat y x permutations 1)
             p-value3 (permute-t-stat y x permutations 2)]

         ; Assert
         (is (double= p-value1
                      [0 0 0]))
         (is (double= p-value2
                      [0 0 0]))
         (is (double= p-value3
                      [1/4 -0.174352447854375 0.674352447854375]))))))
